@@ -4,11 +4,8 @@ from decimal import Decimal
 
 from trytond.pool import PoolMeta
 
-__all__ = ['LandedCost']
 
-
-class LandedCost:
-    __metaclass__ = PoolMeta
+class LandedCost(metaclass=PoolMeta):
     __name__ = 'account.landed_cost'
 
     @classmethod
@@ -19,11 +16,12 @@ class LandedCost:
     def allocate_cost_by_weight(self):
         self._allocate_cost(self._get_weight_factors())
 
+    def unallocate_cost_by_weight(self):
+        self._allocate_cost(self._get_weight_factors(), sign=-1)
+
     def _get_weight_factors(self):
         "Return the factor for each move based on weight"
-        moves = [m for s in self.shipments for m in s.incoming_moves
-            if m.state != 'cancel']
-
+        moves = self.stock_moves()
         sum_weight = Decimal(0)
         weights = {}
         for move in moves:
